==> zio-aws-cloudfront_2.13-5.19.33.1-sources.jar: zio/aws/cloudfront/model/OriginRequestPolicyQueryStringBehavior.scala <==
package zio.aws.cloudfront.model
import scala.jdk.CollectionConverters._
sealed trait OriginRequestPolicyQueryStringBehavior {
  def unwrap: software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior
}
object OriginRequestPolicyQueryStringBehavior {
  def wrap(
      value: software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior
  ): zio.aws.cloudfront.model.OriginRequestPolicyQueryStringBehavior =
    value match {
      case software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.UNKNOWN_TO_SDK_VERSION =>
        val r = unknownToSdkVersion
        r
      case software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.NONE =>
        val r = none
        r
      case software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.WHITELIST =>
        val r = whitelist
        r
      case software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.ALL =>
        val r = all
        r
    }
  case object unknownToSdkVersion
      extends zio.aws.cloudfront.model.OriginRequestPolicyQueryStringBehavior {
    override def unwrap
        : software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior =
      software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.UNKNOWN_TO_SDK_VERSION
  }
  case object none
      extends zio.aws.cloudfront.model.OriginRequestPolicyQueryStringBehavior {
    override def unwrap
        : software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior =
      software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.NONE
  }
  case object whitelist
      extends zio.aws.cloudfront.model.OriginRequestPolicyQueryStringBehavior {
    override def unwrap
        : software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior =
      software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.WHITELIST
  }
  case object all
      extends zio.aws.cloudfront.model.OriginRequestPolicyQueryStringBehavior {
    override def unwrap
        : software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior =
      software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.ALL
  }
}

==> zio-aws-cloudfront_2.13-7.28.29.7-sources.jar: zio/aws/cloudfront/model/OriginRequestPolicyQueryStringBehavior.scala <==
package zio.aws.cloudfront.model
import scala.jdk.CollectionConverters._
sealed trait OriginRequestPolicyQueryStringBehavior {
  def unwrap: software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior
}
object OriginRequestPolicyQueryStringBehavior {
  def wrap(
      value: software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior
  ): zio.aws.cloudfront.model.OriginRequestPolicyQueryStringBehavior =
    value match {
      case software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.UNKNOWN_TO_SDK_VERSION =>
        val r = unknownToSdkVersion
        r
      case software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.NONE =>
        val r = none
        r
      case software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.WHITELIST =>
        val r = whitelist
        r
      case software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.ALL =>
        val r = all
        r
      case software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.ALL_EXCEPT =>
        val r = allExcept
        r
    }
  case object unknownToSdkVersion
      extends zio.aws.cloudfront.model.OriginRequestPolicyQueryStringBehavior {
    override def unwrap
        : software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior =
      software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.UNKNOWN_TO_SDK_VERSION
  }
  case object none
      extends zio.aws.cloudfront.model.OriginRequestPolicyQueryStringBehavior {
    override def unwrap
        : software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior =
      software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.NONE
  }
  case object whitelist
      extends zio.aws.cloudfront.model.OriginRequestPolicyQueryStringBehavior {
    override def unwrap
        : software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior =
      software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.WHITELIST
  }
  case object all
      extends zio.aws.cloudfront.model.OriginRequestPolicyQueryStringBehavior {
    override def unwrap
        : software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior =
      software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.ALL
  }
  case object allExcept
      extends zio.aws.cloudfront.model.OriginRequestPolicyQueryStringBehavior {
    override def unwrap
        : software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior =
      software.amazon.awssdk.services.cloudfront.model.OriginRequestPolicyQueryStringBehavior.ALL_EXCEPT
  }
}
